BaseChangeScore
====================================================

.. currentmodule:: skchange.change_scores

.. autoclass:: BaseChangeScore

.. include:: skchange.change_scores.BaseChangeScore.examples

.. raw:: html

    <div class="clearer"></div>